@@ -19,7 +19,7 @@ def add_dataset_args(parser):
 		_args = [
 			Arg("data", default=DEFAULT_INFO_FILE),
 			Arg("dataset", choices=info_file.DATASETS.keys()),
-			Arg("parts", choices=info_file.PARTS.keys()),
+			Arg("parts", choices=info_file.PART_TYPES.keys()),
 		]
 
 	_args.extend([
@@ -30,6 +30,9 @@ def add_dataset_args(parser):
 		Arg("--swap_channels", action="store_true",
 			help="preprocessing option: swap channels from RGB to BGR"),
 
+		Arg("--n_jobs", "-j", type=int, default=0,
+			help="number of loading processes. If 0, then images are loaded in the same process"),
+
 	])
 
 	parser.add_args(_args, group_name="Dataset arguments")
